@@ -10,13 +10,13 @@ OC.L10N.register(
     "New" : "Yeni",
     "New folder" : "Yeni qovluq",
     "Search" : "Axtarış",
+    "Welcome to Bookmarks" : "Əlfəcinlərə xoş gəlmisiniz",
     "Rename folder" : "Qovluğun adını dəyiş",
     "Delete folder" : "Qovluğu sil",
     "Cancel" : "Dayandır",
     "Shared with you" : "Shared with you",
     "Files" : "Fayllar",
-    "Import" : "Əlavə et",
-    "Export" : "Çıxarış",
+    "Settings" : "Quraşdırmalar",
     "Title" : "Başlıq",
     "Link" : "Link",
     "Tags" : "Işarələr",
