@@ -4,9 +4,11 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Move" : "Move",
     "Delete" : "Delete",
+    "Search" : "Search",
     "Cancel" : "Cancel",
     "Shared with you" : "Shared with you",
     "Files" : "Файлы",
+    "Settings" : "Налады",
     "Title" : "Title",
     "Link" : "Link",
     "Notes" : "Notes",
