@@ -6,12 +6,14 @@ OC.L10N.register(
     "Unsupported file type for import" : "Tipo de archivo no admitido para importar",
     "Details" : "Detalles",
     "Rename" : "Renombrar",
+    "Copy link" : "Copiar liga",
     "Move" : "Mover",
     "Delete" : "Borrar",
     "Select all" : "Seleccionar todo",
     "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva ",
+    "Search" : "Buscar",
     "Add a bookmark" : "Agregar un marcador",
     "Delete folder" : "Borrar carpeta",
     "Choose folder" : "Seleccioanr carpeta",
@@ -20,18 +22,16 @@ OC.L10N.register(
     "Recent" : "Reciente",
     "Shared with you" : "Compartido con usted",
     "Files" : "Archivos",
-    "Import" : "Importar",
-    "Export" : "Exportar",
+    "Settings" : "Ajustes",
     "Bookmarklet" : "Marcadores",
     "Title" : "Título",
     "Link" : "Liga",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
-    "Open file" : "Abrir archivo",
+    "Download file" : "Descargar archivo",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
     "Share link" : "Compartir liga",
-    "Copy link" : "Copiar liga",
     "Allow editing" : "Permitir edición",
     "Allow resharing" : "Permitir volver a compartir",
     "Privacy" : "Privacidad",
