@@ -213,7 +213,7 @@ OC.L10N.register(
     "Root Folder" : "Carpeta raíz",
     "Save" : "Guardar",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "El acceso a la red está desactivado de forma predeterminada. Vaya a la configuración de administración de la aplicación de marcadores para permitir la obtención de vistas previas y favicons.",
-    "What's new in Bookmarks?" : "¿Qué hay de nuevo en Marcadores?",
+    "What's new?" : "¿Qué hay de nuevo?",
     "What" : "Qué",
     "Failed to count unavailable bookmarks" : "Error al contar los marcadores no disponibles",
     "Failed to count archived bookmarks" : "Error al contar los marcadores archivados",
