@@ -3,29 +3,35 @@ OC.L10N.register(
     {
     "Details" : "Detalles",
     "Rename" : "Renombrar",
+    "Copy link" : "Copiar liga",
     "Move" : "Mover",
     "Delete" : "Borrar",
     "Select all" : "Seleccionar todo",
+    "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
+    "Search" : "Buscar",
+    "Delete folder" : "Borrar carpeta",
+    "Choose folder" : "Seleccioanr carpeta",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
-    "Import" : "Importar",
-    "Export" : "Exportar",
+    "Shared with you" : "Compartido con usted",
+    "Files" : "Archivos",
+    "Settings" : "Ajustes",
     "Bookmarklet" : "Marcador a código",
-    "Clear data" : "Borrar datos",
     "Title" : "Título",
     "Link" : "Liga",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
+    "Download file" : "Descargar archivo",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
     "Share link" : "Compartir liga",
-    "Copy link" : "Copiar liga",
     "Allow editing" : "Permitir edición",
+    "Allow resharing" : "Permitir volver a compartir",
     "Privacy" : "Privacidad",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
