@@ -10,6 +10,7 @@ OC.L10N.register(
     "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
+    "Search" : "Buscar",
     "Delete folder" : "Borrar carpeta",
     "Choose folder" : "Seleccioanr carpeta",
     "Submit" : "Enviar",
@@ -17,14 +18,13 @@ OC.L10N.register(
     "Recent" : "Reciente",
     "Shared with you" : "Compartido con usted",
     "Files" : "Archivos",
-    "Import" : "Importar",
-    "Export" : "Exportar",
+    "Settings" : "Configuraciones ",
     "Bookmarklet" : "Marcador a código",
     "Title" : "Título",
     "Link" : "Liga",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
-    "Open file" : "Abrir archivo",
+    "Download file" : "Descargar archivo",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
     "Share link" : "Compartir liga",
