@@ -20,8 +20,7 @@ OC.L10N.register(
     "Recent" : "Hiljutised",
     "Shared with you" : "Sinuga jagatud",
     "Files" : "Failid",
-    "Import" : "Impordi",
-    "Export" : "Ekspordi",
+    "Settings" : "Seaded",
     "Title" : "Pealkiri",
     "Link" : "Link",
     "Tags" : "Sildid",
