@@ -17,8 +17,7 @@ OC.L10N.register(
     "Recent" : "Recente",
     "Shared with you" : "Compartite con te",
     "Files" : "Files",
-    "Import" : "Importar",
-    "Export" : "Exportar",
+    "Settings" : "Configurationes",
     "Title" : "Titulo",
     "Link" : "Ligamine",
     "Tags" : "Etiquettas",
