@@ -11,8 +11,7 @@ OC.L10N.register(
     "Cancel" : "﻿ರದ್ದು",
     "Shared with you" : "Shared with you",
     "Files" : "ಕಡತಗಳು",
-    "Import" : "ಆಮದು",
-    "Export" : "ರಫ್ತು",
+    "Settings" : "ಆಯ್ಕೆ",
     "Title" : "ಶೀರ್ಷಿಕೆ",
     "Link" : "ಸಂಪರ್ಕ ಕೊಂಡಿ",
     "Notes" : "Notes",
