@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Bookmarks" : "Grāmatzīmes",
     "No file provided for import" : "Nav norādīta importējamā datne",
-    "Unsupported file type for import" : "Importam neatbalstīts datnes tips",
+    "Unsupported file type for import" : "Neatbalstīts datnes veids ievietošanai",
     "A Bookmark manager for Nextcloud" : "Nextcloud grāmatzīmju pārvaldnieks",
     "Details" : "Detaļas",
     "Rename" : "Pārsaukt",
@@ -30,11 +30,12 @@ OC.L10N.register(
     "Link" : "Saite",
     "Tags" : "Birkas",
     "Notes" : "Piezīmes",
+    "Notes for this bookmark …" : "Šīs grāmatzīmes piezīmes …",
     "Download file" : "Lejupielādēt datni",
     "Owner" : "Īpašnieks",
     "Sharing" : "Koplietošana",
     "Share link" : "Koplietot saiti",
-    "Allow editing" : "Atļaut rediģēšanu",
+    "Allow editing" : "Atļaut labošanu",
     "Allow resharing" : "Atļaut atkārtotu koplietošanu",
     "Link copied" : "Saite nokopēta",
     "Privacy" : "Privātums",
