@@ -9,8 +9,7 @@ OC.L10N.register(
     "Cancel" : "Batal",
     "Shared with you" : "Shared with you",
     "Files" : "Fail",
-    "Import" : "Import",
-    "Export" : "Eksport",
+    "Settings" : "Tetapan",
     "Title" : "Judul",
     "Link" : "Link",
     "Notes" : "Nota",
