@@ -15,8 +15,7 @@ OC.L10N.register(
     "Cancel" : "Avbryt",
     "Shared with you" : "Shared with you",
     "Files" : "Filer",
-    "Import" : "Importer",
-    "Export" : "Eksporter",
+    "Settings" : "Innstillingar",
     "Title" : "Tittel",
     "Link" : "Lenkje",
     "Tags" : "Emneord",
