@@ -36,8 +36,7 @@ OC.L10N.register(
     "Recent" : "Recents",
     "Shared with you" : "Partejat amb vos",
     "Files" : "Fichièrs",
-    "Import" : "Importar",
-    "Export" : "Exportar",
+    "Settings" : "Paramètres",
     "Title" : "Títol",
     "Link" : "Ligam",
     "Tags" : "Etiquetas",
@@ -45,6 +44,7 @@ OC.L10N.register(
     "Owner" : "Owner",
     "Sharing" : "Partiment",
     "Share link" : "Partejar lo ligam",
+    "Editing allowed" : "Modificacion autorizada",
     "Allow editing" : "Permetre la modificacion",
     "Link copied" : "Ligam copiat",
     "Privacy" : "Confidencialitat",
