@@ -35,6 +35,7 @@ OC.L10N.register(
     "Privacy" : "Confindențialitate",
     "Performance" : "Performanța",
     "Folder" : "Director",
-    "Save" : "Salvează"
+    "Save" : "Salvează",
+    "What's new?" : "Ce este nou?"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
