@@ -9,13 +9,16 @@ OC.L10N.register(
     "Go back" : "ආපසු යන්න",
     "New" : "නව",
     "New folder" : "නව බහාලුම",
+    "Search" : "සොයන්න",
     "Enter a link" : "සබැඳියක් ඇතුළත් කරන්න",
     "Select folder" : "බහාලුම තෝරන්න",
     "Cancel" : "අවලංගු කරන්න",
     "Files" : "ගොනු",
+    "Settings" : "සැකසුම්",
+    "Install web app" : "වියමන යෙදුම ස්ථාපනය කරන්න",
     "Link" : "සබැඳිය",
     "Notes" : "සටහන්",
-    "Open file" : "ගොනුව විවෘත කරන්න",
+    "Download file" : "ගොනුව බාගන්න",
     "Owner" : "හිමිකරු",
     "Select a user or group" : "පරිශීලකයෙකු හෝ සමූහයක් තෝරන්න",
     "Allow editing" : "සංස්කරණයට ඉඩ දෙන්න",
