@@ -10,6 +10,7 @@ OC.L10N.register(
     "Go back" : "Shko prapa",
     "New" : "I ri",
     "New folder" : "Dosje e re",
+    "Search" : "Kërko",
     "Rename folder" : "Riemërtoni dosjen",
     "Delete folder" : "Fshini dosjen",
     "Choose folder" : "Zgjidhni dosjen",
@@ -19,14 +20,13 @@ OC.L10N.register(
     "Shared with you" : "E ndarë me ju",
     "Files" : "Skedarët",
     "Untagged" : "E paetiketuar",
-    "Import" : "Import",
-    "Export" : "Eksport",
+    "Settings" : "Rregullimet",
     "Bookmarklet" : "Libër Shënues",
     "Title" : "Titulli",
     "Link" : "Lidhje",
     "Tags" : "Etiketat",
     "Notes" : "Shënime",
-    "Open file" : "Hap skedarin",
+    "Download file" : "Shkarko skedarin",
     "Owner" : "Zotëruesi",
     "Sharing" : "Ndarje",
     "Share link" : "Share link",
