@@ -9,16 +9,16 @@ OC.L10N.register(
     "Select all" : "Označi sve",
     "New" : "Nov",
     "New folder" : "Nova fascikla",
+    "Search" : "Traži",
     "Cancel" : "Otkaži",
     "Shared with you" : "Shared with you",
     "Files" : "Фајлови",
-    "Import" : "Uvezi",
+    "Settings" : "Поставке",
     "Title" : "Naslov",
     "Link" : "Prečica",
     "Root folder" : "Korena fascikla",
     "Tags" : "Oznake",
     "Notes" : "Notes",
-    "Open file" : "Отвори фајл",
     "Owner" : "Vlasnik",
     "Sharing" : "Deljenje",
     "Share link" : "Podeli vezu",
