@@ -18,8 +18,8 @@ OC.L10N.register(
     "Select one or more tags" : "Виберіть одну або кілька міток",
     "New" : "Створити",
     "New folder" : "Новий каталог",
-    "Change to grid view" : "Перехід до перегляду у вигляді сітки",
-    "Change to list view" : "Перейдіть до перегляду у вигляді списку",
+    "Change to grid view" : "Подання сіткою",
+    "Change to list view" : "Подання списком",
     "Search" : "Пошук",
     "Sort by last modified" : "Впорядкувати за останніми змінами",
     "Sort by title" : "Впорядкувати за назвою",
@@ -57,6 +57,7 @@ OC.L10N.register(
     "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
     "Folder" : "Каталог",
     "Save" : "Зберегти",
+    "What's new?" : "Що нового?",
     "What" : "Що?",
     "Failed to load tags" : "Не вдалося завантажити мітки",
     "Failed to fetch bookmarks." : "Не вдалося отримати закладки."
