@@ -215,7 +215,9 @@ OC.L10N.register(
     "Root Folder" : "根資料夾",
     "Save" : "儲存",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "默認情況下，網絡存取處於停用狀態。轉到書籤應用程式的管理員設置，以啟用獲取預覽和網站圖標的功能。",
-    "What's new in Bookmarks?" : "書籤有什麼新功能？",
+    "What's new?" : "有什麼新鮮事？",
+    "Support this project?" : "支援此專案？",
+    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "我開發呢個「書籤」App 嘅工作係靠自願訂閱模式來維持嘅。如果你覺得我嘅工作有價值，就請支持下我嘅工作。此外，你都可以考慮喺 Nextcloud App 商店裏面，幫呢個 App 寫一個評價。多謝你 💙",
     "What" : "甚麼",
     "Failed to count unavailable bookmarks" : "無法點算不可用的書籤",
     "Failed to count archived bookmarks" : "無法點算已封存的書籤",
