@@ -58,14 +58,15 @@ export default {
 		bookmarksById: {},
 		sharesById: {},
 		sharedFoldersById: {},
-		tags: [],
+		tags: null,
 		folders: [],
+		deletedFolders: null,
 		childrenByFolder: {},
 		tokensByFolder: {},
 		countsByFolder: {},
-		unavailableCount: 0,
-		archivedCount: 0,
-		duplicatedCount: 0,
+		unavailableCount: null,
+		archivedCount: null,
+		duplicatedCount: null,
 		selection: {
 			folders: [],
 			bookmarks: [],
@@ -93,7 +94,11 @@ export default {
 			if (Number(id) === -1) {
 				return [{ id: -1, children: state.folders }]
 			}
-			return findFolder(id, state.folders)
+			const folders = findFolder(id, state.folders)
+			if (folders.length) {
+				return folders
+			}
+			return findFolder(id, state.deletedFolders, true)
 		},
 		getFolderChildren: state => id => {
 			return state.childrenByFolder[id] || []
